@@ -2,7 +2,10 @@
 
 set -ex
 
-PKG=less
+export LC_ALL=C
+PKG=vim
+
+dpkg --purge $PKG
 
 # package not installed
 /usr/share/crmsh/utils/crm_rpmcheck.py $PKG | grep error
@@ -16,7 +19,7 @@ dpkg --status $PKG
 /usr/share/crmsh/utils/crm_pkg.py -n $PKG -s latest | grep false
 
 # purge
-/usr/share/crmsh/utils/crm_pkg.py -n $PKG -s removed | grep Purging
+/usr/share/crmsh/utils/crm_pkg.py -n $PKG -s removed | egrep 'Removing|Purging'
 /usr/share/crmsh/utils/crm_rpmcheck.py $PKG | grep error
 
 # clean
